@@ -179,21 +179,32 @@ class VariableClBuilderVideodrvSet(IsoTypeHelper, Variable):
     Нужно ли скачивать пакеты в дистрибутив для установки проприетарных
     драйверов во время загрузки
     """
-    type = "bool"
+    type = "bool3"
     opt = ["--video", "-V"]
     autodetect = False
-    default_value = "off"
+    check_after = 'main.os_linux_system'
+    value = ""
 
     def init(self):
         self.label = _("Include proprietary video drivers")
         self.help = _("include proprietary video drivers")
 
+    def set(self, value):
+        if value == 'auto' or value is None:
+            self.value = "on" if self.Get('main.os_linux_system') == "desktop" else "off"
+        else:
+            self.value = value
+        return self.value
+
     def get(self):
+        if not self.value or self.value == 'auto':
+            self.set('auto')
+            return self.value
         if self.autodetect:
             fn = self.Get('cl_builder_video_driver_path')
             return "on" if path.exists(fn) else "off"
         else:
-            return self.default_value
+            return self.value
 
 
 class VariableClBuilderSourceFilename(Variable):
