@@ -245,9 +245,9 @@ class VariableOsBuilderLinuxShortname(BuilderLinux):
         self.label = _("Building short name")
 
 
-class VariableOsBuilderLinuxVer(Variable):
+class VariableOsBuilderLinuxVer(BuilderLinux):
     """Shortname of system"""
-    value = "live"
+    variable = "os_linux_ver"
 
     def init(self):
         self.label = _("Building system version")
