@@ -181,6 +181,8 @@ class Wsdl(WsdlBase):
                             'update.cl_update_binhost_recheck_set',
                             'cl_builder_with_bdeps_opt_set',),
                     expert=(
+                        'update.cl_update_binhost_choice',
+                        'update.cl_update_rep_hosting_choice',
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
                         'update.cl_update_pretend_set',
